@@ -24,17 +24,19 @@
  */
 package org.slf4j.impl;
 
+import org.junit.Ignore;
 import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.helpers.BogoPerf;
 
+@Ignore
 public class PerfTest {
 
     static long REFERENCE_BIPS = 9000;
 
     @Test
-    public void testBug72() {
+    public void issue63() {
 
         int LEN = 1000 * 1000 * 10;
         debugLoop(LEN); // warm up
